@@ -1,35 +1,49 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*- #
+# Copyright (C) 2010, 2011 Carlos Pais <freemind@lavabit.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from watchvideo.ui_about import Ui_AboutDialog
-from PyQt4 import QtCore, QtGui, QtSvg
+from watchvideo.qt import QtCore, QtGui
 import watchvideo.constants as c
-import os
 
-copyright = "Copyright © 2010 Leonardo Gastón De Luca".decode("UTF-8")
+
+copyright = u"Copyright © 2010, 2011 Carlos Pais"
 
 credits = \
-"""
-Developer(s):
+u"""
+Developers:
 Carlos Pais <freemind@lavabit.com>
-Leonardo Gastón De Luca <leo@kde.org.ar>
 Michał Masłowski <mtjm@mtjm.eu>
 
-Web Developer(s):
-Miguel Angel Souto
+Translators:
+Carlos Pais (pt, es)
+Michał Masłowski (pl)
+Pavel Fric (cs)
 
 Thanks to:
 Python Programming Language <http://www.python.org/>
 Qt4 Libraries <http://qt.nokia.com/products/>
 FFmpeg <http://www.ffmpeg.org/>
 FFmpeg2Theora <http://v2v.cc/~j/ffmpeg2theora/>
-MPlayer <http://www.mplayerhq.hu/>
-python-mplayer <http://code.google.com/p/python-mplayer/>
-MediaInfo <http://mediainfo.sourceforge.net/>
+VLC <http://www.videolan.org/>
 Libnotify
+Leonardo Gastón De Luca
 Mariano Street
+Miguel Angel Souto
 Edgar Morales
-""".decode("UTF-8")
+""".strip()
 
 license = \
 """
@@ -49,7 +63,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 class AboutDialog(QtGui.QDialog):
     def __init__(self, parent):
-        QtGui.QDialog.__init__(self, parent)
+        super(AboutDialog, self).__init__(parent)
         self.ui = Ui_AboutDialog()
         self.ui.setupUi(self)
         
@@ -57,8 +71,8 @@ class AboutDialog(QtGui.QDialog):
         "download or convert videos (to Ogg) from various youtube-like sites.\n" + "It's made in PyQt4.")
         
         #creates a Svg widget
-        svg_icon = QtSvg.QSvgWidget(c.ICON_WATCHVIDEO)
-        svg_icon.setFixedSize(200, 200)
+        svg_icon = QtGui.QLabel()
+        svg_icon.setPixmap(QtGui.QPixmap(":/media/watchvideo-200x200.png"))
         
         label_desc = QtGui.QLabel(description + "\n\n" + 
         copyright + "\n" + self.tr("Version: ") + c.VERSION + " beta")
@@ -76,7 +90,13 @@ class AboutDialog(QtGui.QDialog):
         self.ui.tedit_credits.setText(credits)
         self.ui.tedit_license.setText(license)
         
-        QtCore.QObject.connect(self.ui.b_close, QtCore.SIGNAL("clicked()"), self.close)
+        self.ui.b_close.clicked.connect(self.close)
+    
+    def closeEvent(self, e):
+        self.visible = False
         
+    def show(self):
+        self.visible = True
+        super(AboutDialog, self).show()
         
     
