@@ -20,10 +20,16 @@ Other functions.
 """
 
 
-import os
 import os.path
 
 
+__all__ = ("PATH", "is_executable", "is_command")
+
+
+#: The list of paths searched for executables.
+PATH = os.environ["PATH"].split(os.path.pathsep)
+
+
 def is_executable(path):
     """Return `True` if `path` exists, is file and is executable."""
     if not os.path.isfile(path):
@@ -35,7 +41,7 @@ def is_command(prog):
     """Return `True` if `prog` is found as program."""
     if is_executable(prog):
         return True
-    for path in os.environ["PATH"].split(os.path.pathsep):
+    for path in PATH:
         if is_executable(os.path.join(path, prog)):
             return True
     return False
